@@ -1,23 +1,9 @@
 /*
  * This file is part of LibKGAPI library
  *
- * Copyright (C) 2013  Daniel Vrátil <dvratil@redhat.com>
+ * SPDX-FileCopyrightText: 2013 Daniel Vrátil <dvratil@redhat.com>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) version 3, or any
- * later version accepted by the membership of KDE e.V. (or its
- * successor approved by the membership of KDE e.V.), which shall
- * act as a proxy defined in Section 6 of version 3 of the license.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library.  If not, see <https://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
  */
 
 #include "contactmodifyjob.h"
@@ -41,12 +27,13 @@ class Q_DECL_HIDDEN ContactModifyJob::Private
   public:
     Private(ContactModifyJob *parent);
     void processNextContact();
+    void updatePhoto(const ContactPtr &contact);
 
     QueueHelper<ContactPtr> contacts;
     ContactPtr lastContact;
     QPair<QByteArray, QString> pendingPhoto;
   private:
-    ContactModifyJob *q;
+    ContactModifyJob *const q;
 };
 
 ContactModifyJob::Private::Private(ContactModifyJob *parent):
@@ -84,7 +71,10 @@ void ContactModifyJob::Private::processNextContact()
     }
 
     q->enqueueRequest(request, rawData, QStringLiteral("application/atom+xml"));
+}
 
+void ContactModifyJob::Private::updatePhoto(const ContactPtr &contact)
+{
     const QUrl photoUrl = ContactsService::photoUrl(q->account()->accountName(), contact->uid());
     QNetworkRequest photoRequest(photoUrl);
     if (!contact->photo().isEmpty()) {
@@ -94,7 +84,7 @@ void ContactModifyJob::Private::processNextContact()
         q->enqueueRequest(photoRequest, pendingPhoto.first, QStringLiteral("modifyImage"));
     } else {
         q->enqueueRequest(photoRequest, QByteArray(), QStringLiteral("deleteImage"));
-  }
+    }
 }
 
 
@@ -154,17 +144,17 @@ ObjectsList ContactModifyJob::handleReplyWithItems(const QNetworkReply *reply, c
         if (ct == KGAPI2::JSON) {
             d->lastContact = ContactsService::JSONToContact(rawData);
             items << d->lastContact;
-            d->contacts.currentProcessed();
         } else if (ct == KGAPI2::XML) {
             d->lastContact = ContactsService::XMLToContact(rawData);
             items << d->lastContact;
-            d->contacts.currentProcessed();
         } else {
             setError(KGAPI2::InvalidResponse);
             setErrorString(tr("Invalid response content type"));
             emitFinished();
             return items;
         }
+        d->updatePhoto(d->contacts.current());
+        d->contacts.currentProcessed();
     } else {
         if (d->lastContact && !d->pendingPhoto.first.isEmpty()) {
             KContacts::Picture picture;
